Class: Langfuse::BatchWorker
- Inherits:
-
Object
- Object
- Langfuse::BatchWorker
- Includes:
- Sidekiq::Worker
- Defined in:
- lib/langfuse/batch_worker.rb,
lib/langfuse/batch_worker.rb
Class Method Summary collapse
-
.perform_async(events) ⇒ Object
This is a placeholder class that will be defined with Sidekiq::Worker when Sidekiq is available.
Instance Method Summary collapse
Class Method Details
.perform_async(events) ⇒ Object
This is a placeholder class that will be defined with Sidekiq::Worker when Sidekiq is available.
If Sidekiq is available, this will be replaced with a real worker class that includes Sidekiq::Worker
9 10 11 12 |
# File 'lib/langfuse/batch_worker.rb', line 9 def self.perform_async(events) # When Sidekiq is not available, process synchronously new.perform(events) end |
Instance Method Details
#perform(event_hashes) ⇒ Object
14 15 16 |
# File 'lib/langfuse/batch_worker.rb', line 14 def perform(events) Langfuse::ApiClient.new(Langfuse.configuration).ingest(events) end |